@@ -9,7 +9,7 @@ import fire
 class Regbot:
   reg_model_path = resource_filename(__name__, 'btc_model.h5') 
   model_scaler_path = resource_filename(__name__, 'btclogscaler.gz') 
-
+  thr = 0.49503654254794244
 
   def __init__(self,*args):
   	pass
@@ -21,12 +21,15 @@ class Regbot:
     loaded_model = joblib.load(open(f'{cls.reg_model_path}', 'rb'))
     return loaded_model
 
+  @classmethod
+  def getUtcHour(cls,utcdatetime):
+    return str(utcdatetime).split(' ')[1][1]
 
   @classmethod  
-  def prepareInput(cls,opening,closing,utcdate):
+  def prepareInput(cls,opening,closing,utcdatetime):
     avr = closing/(opening + closing)
     bvr = opening/(opening + closing)
-    utctime = utcdate.split(' ')[1][1]
+    utctime = cls.getUtcHour(utcdatetime)
     testdata = np.array([[avr,bvr,utctime]])
     scaler = joblib.load(f'{cls.model_scaler_path}')
     testdata = scaler.transform(testdata)
@@ -35,17 +38,17 @@ class Regbot:
 
 
   @classmethod
-  def buySignalGenerator(cls,opening,closing,utcdate):
-    scalledInput = cls.prepareInput(opening,closing,utcdate)
-    return np.round(np.clip(cls.loadmodel().predict(scalledInput), 0, 1) > 0)[0].astype(int)
+  def buySignalGenerator(cls,opening,closing,utcdatetime):
+    scalledInput = cls.prepareInput(opening,closing,utcdatetime)
+    return (cls.loadmodel().predict_proba(scalledInput)[:,1] > cls.thr).astype(int)[0]
 
 
 
 
 
-def signal(opening, closing,utcdate):
+def signal(opening, closing,utcdatetime):
   try:
-    return Regbot.buySignalGenerator(opening,closing,utcdate)
+    return Regbot.buySignalGenerator(opening,closing,utcdatetime)
   except Exception as e:
     print(e)
 
